@@ -10,13 +10,7 @@ from pathlib import Path
 from typing import Dict, Optional, Union
 
 from jina import __resources_path__, __version__
-from jina.helper import (
-    ArgNamespace,
-    colored,
-    get_request_header,
-    get_rich_console,
-    retry,
-)
+from jina.helper import ArgNamespace, get_rich_console, retry
 from jina.hubble import HubExecutor
 from jina.hubble.helper import (
     archive_package,
@@ -26,6 +20,7 @@ from jina.hubble.helper import (
     get_download_cache_dir,
     get_hubble_error_message,
     get_hubble_url_v2,
+    get_request_header,
     parse_hub_uri,
     upload_file,
 )
@@ -393,7 +388,7 @@ metas:
                     form_data['secret'] = self.args.secret or secret
 
                 st.update(f'Connecting to Jina Hub ...')
-                if form_data.get('id') and form_data.get('secret'):
+                if form_data.get('id'):
                     hubble_url = get_hubble_url_v2() + '/rpc/executor.update'
                 else:
                     hubble_url = get_hubble_url_v2() + '/rpc/executor.create'
@@ -411,6 +406,7 @@ metas:
                 )
 
                 image = None
+                warning = None
                 session_id = req_header.get('jinameta-session-id')
                 for stream_line in resp.iter_lines():
                     stream_msg = json.loads(stream_line)
@@ -444,6 +440,7 @@ metas:
                         )
                     elif t == 'complete':
                         image = stream_msg['payload']
+                        warning = stream_msg.get('warning')
                         st.update(
                             f'Cloud building ... [dim]{subject}: {t} ({stream_msg["message"]})[/dim]'
                         )
@@ -459,9 +456,11 @@ metas:
                             )
 
                 if image:
-                    new_uuid8, new_secret = self._prettyprint_result(console, image)
+                    new_uuid8, new_secret = self._prettyprint_result(
+                        console, image, warning=warning
+                    )
                     if new_uuid8 != uuid8 or new_secret != secret:
-                        dump_secret(work_path, new_uuid8, new_secret)
+                        dump_secret(work_path, new_uuid8, new_secret or '')
                 else:
                     raise Exception(f'Unknown Error, session_id: {session_id}')
 
@@ -474,33 +473,44 @@ metas:
                 )
                 raise e
 
-    def _prettyprint_result(self, console, image):
+    def _prettyprint_result(self, console, image, *, warning: Optional[str] = None):
         # TODO: only support single executor now
 
+        from rich import box
         from rich.panel import Panel
         from rich.table import Table
 
         uuid8 = image['id']
-        secret = image['secret']
+        secret = image.get('secret')
         visibility = image['visibility']
         tag = self.args.tag[0] if self.args.tag else None
 
-        table = Table.grid()
-        table.add_column(width=20, no_wrap=True)
-        table.add_column(style='cyan', no_wrap=True)
+        table = Table(box=box.SIMPLE, show_header=False)
+        table.add_column(no_wrap=True)
+        table.add_column(no_wrap=True)
+        if 'name' in image:
+            table.add_row(':name_badge: Name', image['name'])
+
         table.add_row(
             ':link: Hub URL',
             f'[link=https://hub.jina.ai/executor/{uuid8}/]https://hub.jina.ai/executor/{uuid8}/[/link]',
         )
-        if 'name' in image:
-            table.add_row(':name_badge: Name', image['name'])
-        table.add_row(':lock: Secret', secret)
-        table.add_row(
-            '',
-            ':point_up:️ [bold red]Please keep this token in a safe place!',
-        )
+
+        if secret:
+            table.add_row(':lock: Secret', secret)
+            table.add_row(
+                '',
+                ':point_up:️ [bold red]Please keep this token in a safe place!',
+            )
+
         table.add_row(':eyes: Visibility', visibility)
 
+        if warning:
+            table.add_row(
+                ':warning: Warning',
+                f':exclamation:️ [bold yellow]{warning}',
+            )
+
         p1 = Panel(
             table,
             title='Published',
@@ -511,7 +521,9 @@ metas:
 
         presented_id = image.get('name', uuid8)
         usage = (
-            f'{presented_id}' if visibility == 'public' else f'{presented_id}:{secret}'
+            f'{presented_id}'
+            if visibility == 'public' or not secret
+            else f'{presented_id}:{secret}'
         ) + (f'/{tag}' if tag else '')
 
         if not self.args.no_usage:
@@ -520,48 +532,36 @@ metas:
         return uuid8, secret
 
     def _get_prettyprint_usage(self, console, executor_name, usage_kind=None):
+        from rich import box
         from rich.panel import Panel
         from rich.syntax import Syntax
+        from rich.table import Table
 
-        flow_plain = f'''from jina import Flow
+        param_str = Table(
+            box=box.SIMPLE,
+        )
+        param_str.add_column('')
+        param_str.add_column('YAML')
+        param_str.add_column('Python')
+        param_str.add_row(
+            'Container',
+            Syntax(f"uses: jinahub+docker://{executor_name}", 'yaml'),
+            Syntax(f".add(uses='jinahub+docker://{executor_name}')", 'python'),
+        )
 
-f = Flow().add(uses='jinahub://{executor_name}')
-'''
+        param_str.add_row(
+            'Sandbox',
+            Syntax(f"uses: jinahub+sandbox://{executor_name}", 'yaml'),
+            Syntax(f".add(uses='jinahub+sandbox://{executor_name}')", 'python'),
+        )
 
-        flow_docker = f'''from jina import Flow
+        param_str.add_row(
+            'Source',
+            Syntax(f"uses: jinahub://{executor_name}", 'yaml'),
+            Syntax(f".add(uses='jinahub://{executor_name}')", 'python'),
+        )
 
-f = Flow().add(uses='jinahub+docker://{executor_name}')
-'''
-
-        flow_sandbox = f'''from jina import Flow
-
-f = Flow().add(uses='jinahub+sandbox://{executor_name}')
-'''
-        panels = [
-            Panel(
-                Syntax(
-                    p[0],
-                    'python',
-                    theme='monokai',
-                    word_wrap=True,
-                ),
-                title=p[1],
-                width=80,
-                expand=False,
-            )
-            for p in [
-                (flow_plain, 'Use via source'),
-                (flow_docker, 'Use in Docker'),
-                (flow_sandbox, 'Use in Sandbox'),
-            ]
-        ]
-
-        if usage_kind == 'docker':
-            console.print(panels[1])
-        elif usage_kind == 'source':
-            console.print(panels[0])
-        else:
-            console.print(*reversed(panels))
+        console.print(Panel(param_str, title='Usage', expand=False, width=100))
 
     @staticmethod
     @disk_cache_offline(cache_file=str(get_cache_db()))
@@ -654,6 +654,7 @@ f = Flow().add(uses='jinahub+sandbox://{executor_name}')
             'tag': tag if tag else 'latest',
             'jina': __version__,
             'args': args_copy,
+            'secret': secret,
         }
 
         import requests
@@ -786,10 +787,10 @@ f = Flow().add(uses='jinahub+sandbox://{executor_name}')
                     force=need_pull,
                 )
 
-                presented_id = getattr(executor, 'name', executor.uuid)
+                presented_id = executor.name if executor.name else executor.uuid
                 executor_name = (
                     f'{presented_id}'
-                    if executor.visibility == 'public'
+                    if executor.visibility == 'public' or not secret
                     else f'{presented_id}:{secret}'
                 ) + (f'/{tag}' if tag else '')
 
