@@ -3,7 +3,7 @@
 import argparse
 import os
 
-from ..helper import add_arg_group
+from jina.parsers.helper import add_arg_group
 
 
 def mixin_hub_push_parser(parser):
@@ -17,6 +17,13 @@ def mixin_hub_push_parser(parser):
         else:
             raise NotADirectoryError(string)
 
+    parser.add_argument(
+        '--verbose',
+        action='store_true',
+        default=False,
+        help='If set, more information will be printed.',
+    )
+
     gp = add_arg_group(parser, title='Push')
     gp.add_argument(
         'path',
@@ -42,6 +49,12 @@ One can later fetch a tagged Executor via `jinahub[+docker]://MyExecutor/gpu`
 ''',
     )
 
+    gp.add_argument(
+        '--protected-tag',
+        action='append',
+        help='A list of protected tags. Like tag but protected against updates after first push.',
+    )
+
     gp.add_argument(
         '--force-update',
         '--force',
@@ -54,6 +67,13 @@ One can later fetch a tagged Executor via `jinahub[+docker]://MyExecutor/gpu`
         help='The secret for overwrite a Hub executor',
     )
 
+    gp.add_argument(
+        '--no-cache',
+        action='store_true',
+        default=False,
+        help='If set, "--no-cache" option will be added to the Docker build.',
+    )
+
     gp = add_arg_group(parser, title='Visibility')
 
     mutually_exclusive_group = gp.add_mutually_exclusive_group()
